==> haskell-optparse-simple-0.1.1.4-452-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-simple
version:              0.1.1.4
visibility:           public
id:                   optparse-simple-0.1.1.4-8geJfJfHrVG5VZu7ni5iN0
key:                  optparse-simple-0.1.1.4-8geJfJfHrVG5VZu7ni5iN0
license:              BSD-3-Clause
copyright:            2015-2017 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               FP Complete
homepage:             https://github.com/fpco/optparse-simple#readme
synopsis:             Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>

category:             Options
abi:                  3b692f1bef8a2236a9514e9cfe45b086
exposed:              True
exposed-modules:      Options.Applicative.Simple
hidden-modules:       Paths_optparse_simple
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-simple
hs-libraries:         HSoptparse-simple-0.1.1.4-8geJfJfHrVG5VZu7ni5iN0
depends:
    base-4.17.2.1 githash-0.1.6.3-11jnrk28U0G11QUnE5ZUS
    optparse-applicative-0.18.1.0-HLRS0wxhkSb4kVPN7e82uH
    template-haskell-2.19.0.0 th-compat-0.1.6-1rozPINXRhGEtC14TOvrVH
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock

haddock-html:         /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-simple-0.1.1.4-453-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-simple
version:              0.1.1.4
visibility:           public
id:                   optparse-simple-0.1.1.4-HdslXvAEBFV1gUGgJ8X3eb
key:                  optparse-simple-0.1.1.4-HdslXvAEBFV1gUGgJ8X3eb
license:              BSD-3-Clause
copyright:            2015-2017 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               FP Complete
homepage:             https://github.com/fpco/optparse-simple#readme
synopsis:             Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>

category:             Options
abi:                  f0721fd60d8c3c8794d24a2a2a771ad9
exposed:              True
exposed-modules:      Options.Applicative.Simple
hidden-modules:       Paths_optparse_simple
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-simple
hs-libraries:         HSoptparse-simple-0.1.1.4-HdslXvAEBFV1gUGgJ8X3eb
depends:
    base-4.17.2.1 githash-0.1.6.3-J2nSnk9GDaPFxHSmFMiscc
    optparse-applicative-0.18.1.0-GDwWCLBUeEeIARGaJHYM6i
    template-haskell-2.19.0.0 th-compat-0.1.6-9GxM1RYqHEeIUBUN5fSo1l
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock

haddock-html:         /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
